@@ -5,4 +5,8 @@ from .utils.paths import (
     assets_dir, config
 )
 
-from .utils.render import console, errors
\ No newline at end of file
+from .utils.render import console, errors
+
+from .cli.query import qapp
+from .cli.run import run
+from .cli.execute import exe
\ No newline at end of file
