@@ -1,6 +1,6 @@
 from .paths import (
     package_dir, base_dir, tests_dir,
-    assets_dir, data_dir, config
+    assets_dir, data_dir, config, pisql_home
 )
 
 from .render import console, errors
\ No newline at end of file
